==> huaweicloudsdkservicestage-3.0.52-py2.py3-none-any.whl: huaweicloudsdkservicestage/v2/model/instance_create.py <==
# coding: utf-8

import re
import six





class InstanceCreate:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'environment_id': 'str',
        'flavor_id': 'FlavorId',
        'replica': 'int',
        'artifacts': 'dict(str, object)',
        'version': 'str',
        'configuration': 'object',
        'description': 'str',
        'external_accesses': 'list[ExternalAccessesCreate]',
        'refer_resources': 'list[ReferResourceCreate]'
    }

    attribute_map = {
        'name': 'name',
        'environment_id': 'environment_id',
        'flavor_id': 'flavor_id',
        'replica': 'replica',
        'artifacts': 'artifacts',
        'version': 'version',
        'configuration': 'configuration',
        'description': 'description',
        'external_accesses': 'external_accesses',
        'refer_resources': 'refer_resources'
    }

    def __init__(self, name=None, environment_id=None, flavor_id=None, replica=None, artifacts=None, version=None, configuration=None, description=None, external_accesses=None, refer_resources=None):
        """InstanceCreate - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._environment_id = None
        self._flavor_id = None
        self._replica = None
        self._artifacts = None
        self._version = None
        self._configuration = None
        self._description = None
        self._external_accesses = None
        self._refer_resources = None
        self.discriminator = None

        self.name = name
        self.environment_id = environment_id
        self.flavor_id = flavor_id
        self.replica = replica
        self.artifacts = artifacts
        self.version = version
        if configuration is not None:
            self.configuration = configuration
        if description is not None:
            self.description = description
        if external_accesses is not None:
            self.external_accesses = external_accesses
        self.refer_resources = refer_resources

    @property
    def name(self):
        """Gets the name of this InstanceCreate.

        应用组件实例名称。

        :return: The name of this InstanceCreate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InstanceCreate.

        应用组件实例名称。

        :param name: The name of this InstanceCreate.
        :type: str
        """
        self._name = name

    @property
    def environment_id(self):
        """Gets the environment_id of this InstanceCreate.

        环境ID。

        :return: The environment_id of this InstanceCreate.
        :rtype: str
        """
        return self._environment_id

    @environment_id.setter
    def environment_id(self, environment_id):
        """Sets the environment_id of this InstanceCreate.

        环境ID。

        :param environment_id: The environment_id of this InstanceCreate.
        :type: str
        """
        self._environment_id = environment_id

    @property
    def flavor_id(self):
        """Gets the flavor_id of this InstanceCreate.


        :return: The flavor_id of this InstanceCreate.
        :rtype: FlavorId
        """
        return self._flavor_id

    @flavor_id.setter
    def flavor_id(self, flavor_id):
        """Sets the flavor_id of this InstanceCreate.


        :param flavor_id: The flavor_id of this InstanceCreate.
        :type: FlavorId
        """
        self._flavor_id = flavor_id

    @property
    def replica(self):
        """Gets the replica of this InstanceCreate.

        实例副本数。

        :return: The replica of this InstanceCreate.
        :rtype: int
        """
        return self._replica

    @replica.setter
    def replica(self, replica):
        """Sets the replica of this InstanceCreate.

        实例副本数。

        :param replica: The replica of this InstanceCreate.
        :type: int
        """
        self._replica = replica

    @property
    def artifacts(self):
        """Gets the artifacts of this InstanceCreate.

        组件部署件。key为组件component_name，对于Docker多容器场景，key为容器名称。

        :return: The artifacts of this InstanceCreate.
        :rtype: dict(str, object)
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this InstanceCreate.

        组件部署件。key为组件component_name，对于Docker多容器场景，key为容器名称。

        :param artifacts: The artifacts of this InstanceCreate.
        :type: dict(str, object)
        """
        self._artifacts = artifacts

    @property
    def version(self):
        """Gets the version of this InstanceCreate.

        应用组件版本号，满足版本语义，如1.0.0。。

        :return: The version of this InstanceCreate.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InstanceCreate.

        应用组件版本号，满足版本语义，如1.0.0。。

        :param version: The version of this InstanceCreate.
        :type: str
        """
        self._version = version

    @property
    def configuration(self):
        """Gets the configuration of this InstanceCreate.

        应用配置，环境变量等，如{“env”: [{“name”: “log-level”: “warn”}]}, 默认空。

        :return: The configuration of this InstanceCreate.
        :rtype: object
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this InstanceCreate.

        应用配置，环境变量等，如{“env”: [{“name”: “log-level”: “warn”}]}, 默认空。

        :param configuration: The configuration of this InstanceCreate.
        :type: object
        """
        self._configuration = configuration

    @property
    def description(self):
        """Gets the description of this InstanceCreate.

        描述。

        :return: The description of this InstanceCreate.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InstanceCreate.

        描述。

        :param description: The description of this InstanceCreate.
        :type: str
        """
        self._description = description

    @property
    def external_accesses(self):
        """Gets the external_accesses of this InstanceCreate.

        访问方式。

        :return: The external_accesses of this InstanceCreate.
        :rtype: list[ExternalAccessesCreate]
        """
        return self._external_accesses

    @external_accesses.setter
    def external_accesses(self, external_accesses):
        """Sets the external_accesses of this InstanceCreate.

        访问方式。

        :param external_accesses: The external_accesses of this InstanceCreate.
        :type: list[ExternalAccessesCreate]
        """
        self._external_accesses = external_accesses

    @property
    def refer_resources(self):
        """Gets the refer_resources of this InstanceCreate.

        部署资源。

        :return: The refer_resources of this InstanceCreate.
        :rtype: list[ReferResourceCreate]
        """
        return self._refer_resources

    @refer_resources.setter
    def refer_resources(self, refer_resources):
        """Sets the refer_resources of this InstanceCreate.

        部署资源。

        :param refer_resources: The refer_resources of this InstanceCreate.
        :type: list[ReferResourceCreate]
        """
        self._refer_resources = refer_resources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkservicestage-3.0.54-py2.py3-none-any.whl: huaweicloudsdkservicestage/v2/model/instance_create.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class InstanceCreate:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'environment_id': 'str',
        'flavor_id': 'FlavorId',
        'replica': 'int',
        'artifacts': 'dict(str, object)',
        'version': 'str',
        'configuration': 'object',
        'description': 'str',
        'external_accesses': 'list[ExternalAccessesCreate]',
        'refer_resources': 'list[ReferResourceCreate]'
    }

    attribute_map = {
        'name': 'name',
        'environment_id': 'environment_id',
        'flavor_id': 'flavor_id',
        'replica': 'replica',
        'artifacts': 'artifacts',
        'version': 'version',
        'configuration': 'configuration',
        'description': 'description',
        'external_accesses': 'external_accesses',
        'refer_resources': 'refer_resources'
    }

    def __init__(self, name=None, environment_id=None, flavor_id=None, replica=None, artifacts=None, version=None, configuration=None, description=None, external_accesses=None, refer_resources=None):
        """InstanceCreate - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._environment_id = None
        self._flavor_id = None
        self._replica = None
        self._artifacts = None
        self._version = None
        self._configuration = None
        self._description = None
        self._external_accesses = None
        self._refer_resources = None
        self.discriminator = None

        self.name = name
        self.environment_id = environment_id
        self.flavor_id = flavor_id
        self.replica = replica
        self.artifacts = artifacts
        self.version = version
        if configuration is not None:
            self.configuration = configuration
        if description is not None:
            self.description = description
        if external_accesses is not None:
            self.external_accesses = external_accesses
        self.refer_resources = refer_resources

    @property
    def name(self):
        """Gets the name of this InstanceCreate.

        应用组件实例名称。

        :return: The name of this InstanceCreate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InstanceCreate.

        应用组件实例名称。

        :param name: The name of this InstanceCreate.
        :type: str
        """
        self._name = name

    @property
    def environment_id(self):
        """Gets the environment_id of this InstanceCreate.

        环境ID。

        :return: The environment_id of this InstanceCreate.
        :rtype: str
        """
        return self._environment_id

    @environment_id.setter
    def environment_id(self, environment_id):
        """Sets the environment_id of this InstanceCreate.

        环境ID。

        :param environment_id: The environment_id of this InstanceCreate.
        :type: str
        """
        self._environment_id = environment_id

    @property
    def flavor_id(self):
        """Gets the flavor_id of this InstanceCreate.


        :return: The flavor_id of this InstanceCreate.
        :rtype: FlavorId
        """
        return self._flavor_id

    @flavor_id.setter
    def flavor_id(self, flavor_id):
        """Sets the flavor_id of this InstanceCreate.


        :param flavor_id: The flavor_id of this InstanceCreate.
        :type: FlavorId
        """
        self._flavor_id = flavor_id

    @property
    def replica(self):
        """Gets the replica of this InstanceCreate.

        实例副本数。

        :return: The replica of this InstanceCreate.
        :rtype: int
        """
        return self._replica

    @replica.setter
    def replica(self, replica):
        """Sets the replica of this InstanceCreate.

        实例副本数。

        :param replica: The replica of this InstanceCreate.
        :type: int
        """
        self._replica = replica

    @property
    def artifacts(self):
        """Gets the artifacts of this InstanceCreate.

        组件部署件。key为组件component_name，对于Docker多容器场景，key为容器名称。

        :return: The artifacts of this InstanceCreate.
        :rtype: dict(str, object)
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this InstanceCreate.

        组件部署件。key为组件component_name，对于Docker多容器场景，key为容器名称。

        :param artifacts: The artifacts of this InstanceCreate.
        :type: dict(str, object)
        """
        self._artifacts = artifacts

    @property
    def version(self):
        """Gets the version of this InstanceCreate.

        应用组件版本号，满足版本语义，如1.0.0。。

        :return: The version of this InstanceCreate.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InstanceCreate.

        应用组件版本号，满足版本语义，如1.0.0。。

        :param version: The version of this InstanceCreate.
        :type: str
        """
        self._version = version

    @property
    def configuration(self):
        """Gets the configuration of this InstanceCreate.

        应用配置，环境变量等，如{“env”: [{“name”: “log-level”: “warn”}]}, 默认空。

        :return: The configuration of this InstanceCreate.
        :rtype: object
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this InstanceCreate.

        应用配置，环境变量等，如{“env”: [{“name”: “log-level”: “warn”}]}, 默认空。

        :param configuration: The configuration of this InstanceCreate.
        :type: object
        """
        self._configuration = configuration

    @property
    def description(self):
        """Gets the description of this InstanceCreate.

        描述。

        :return: The description of this InstanceCreate.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InstanceCreate.

        描述。

        :param description: The description of this InstanceCreate.
        :type: str
        """
        self._description = description

    @property
    def external_accesses(self):
        """Gets the external_accesses of this InstanceCreate.

        访问方式。

        :return: The external_accesses of this InstanceCreate.
        :rtype: list[ExternalAccessesCreate]
        """
        return self._external_accesses

    @external_accesses.setter
    def external_accesses(self, external_accesses):
        """Sets the external_accesses of this InstanceCreate.

        访问方式。

        :param external_accesses: The external_accesses of this InstanceCreate.
        :type: list[ExternalAccessesCreate]
        """
        self._external_accesses = external_accesses

    @property
    def refer_resources(self):
        """Gets the refer_resources of this InstanceCreate.

        部署资源。

        :return: The refer_resources of this InstanceCreate.
        :rtype: list[ReferResourceCreate]
        """
        return self._refer_resources

    @refer_resources.setter
    def refer_resources(self, refer_resources):
        """Sets the refer_resources of this InstanceCreate.

        部署资源。

        :param refer_resources: The refer_resources of this InstanceCreate.
        :type: list[ReferResourceCreate]
        """
        self._refer_resources = refer_resources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
